==> freediams_0.4.2.orig.tar.gz: freediams-0.4.2/global_resources/translations/formmanagerplugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>Form::EpisodeModel</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="1159"/>
        <source>No user</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormFilesSelectorWidget</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.ui" line="26"/>
        <source>Patient&apos;s forms file selector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.ui" line="49"/>
        <source>Actual selected file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.ui" line="84"/>
        <source>Use selected file for the patient&apos;s forms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormMain</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/iformitem.cpp" line="416"/>
        <source>Form : </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormMainDebugPage</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/iformitem.cpp" line="542"/>
        <source>Forms : </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::EpisodeBase</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="221"/>
        <source>Unable to connect the episodes&apos; database host.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="221"/>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="227"/>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="232"/>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="241"/>
        <source>Please contact dev team.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="227"/>
        <source>Unable to create the episodes database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="232"/>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="241"/>
        <source>Unable to connect the episodes database.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::EpisodeModelPrivate</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="565"/>
        <source>Save episode ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="566"/>
        <source>The actual episode has been modified. Do you want to save changes in your database ?
Answering &apos;No&apos; will cause definitve data lose.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="568"/>
        <source>Save episode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::EpisodesCoreListener</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="128"/>
        <source>Save episodes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="129"/>
        <source>Some datas are not actually saved into database.Do you want to save them ?
 Answering &apos;No&apos; will cause definitive data lose.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormManagerMode</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagermode.cpp" line="57"/>
        <source>Patients Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormManagerPreferencesPage</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferencespage.cpp" line="67"/>
        <source>Selector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferencespage.cpp" line="68"/>
        <source>Forms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freediams_0.5.4.orig.tar.gz: freediams-0.5.4/global_resources/translations/formmanagerplugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>Form::EpisodeModel</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="1159"/>
        <source>No user</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormFilesSelectorWidget</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.ui" line="26"/>
        <source>Patient&apos;s forms file selector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.ui" line="49"/>
        <source>Actual selected file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.ui" line="84"/>
        <source>Use selected file for the patient&apos;s forms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormMain</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/iformitem.cpp" line="416"/>
        <source>Form : </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormMainDebugPage</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/iformitem.cpp" line="542"/>
        <source>Forms : </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::EpisodeBase</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="221"/>
        <source>Unable to connect the episodes&apos; database host.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="221"/>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="227"/>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="232"/>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="241"/>
        <source>Please contact dev team.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="227"/>
        <source>Unable to create the episodes database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="232"/>
        <location filename="../../plugins/formmanagerplugin/episodebase.cpp" line="241"/>
        <source>Unable to connect the episodes database.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::EpisodesCoreListener</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="128"/>
        <source>Save episodes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="129"/>
        <source>Some datas are not actually saved into database.Do you want to save them ?
 Answering &apos;No&apos; will cause definitive data lose.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormManagerMode</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagermode.cpp" line="57"/>
        <source>Patients Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormManagerPreferencesPage</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferencespage.cpp" line="67"/>
        <source>Selector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferencespage.cpp" line="68"/>
        <source>Forms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="565"/>
        <source>EpisodeModel</source>
        <comment>Save episode ?</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="566"/>
        <source>EpisodeModel</source>
        <comment>The actual episode has been modified. Do you want to save changes in your database ?
Answering &apos;No&apos; will cause definitve data lose.</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="568"/>
        <source>EpisodeModel</source>
        <comment>Save episode</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
